# IMAS-ParaView
IMAS-ParaView is a tool to convert GGD ([Generalized Grid Description](https://imas-data-dictionary.readthedocs.io/en/latest/ggd_guide/doc.html)) 
structures to VTK formats, and back. This is complemented by a number of Paraview plugins that can visualise both GGD and non-GGD IDS data in Paraview. 

For an overview of the different types of IDS data that can be loaded, see the [documentation](https://imas-paraview.readthedocs.io/en/latest/).

## Installation
For instructions on how to install IMAS-ParaView, please have a look at the [installation instructions](https://imas-paraview.readthedocs.io/en/latest/installing.html).


## Documentation
Documentation is autogenerated from the source using [Sphinx](http://sphinx-doc.org/)
and can be found at the [Read the Docs](https://imas-paraview.readthedocs.io/en/latest/).

The documentation can be manually generated by installing sphinx and running:
```bash
make -C docs html
```
Open `docs/_build/html/index.html`.


If some dependencies are missing, create a python virtual environment and install them:
```bash
python -m venv --system-site-packages venv
source venv/bin/activate
pip install --upgrade .[docs]
make -C docs clean html
```
